@@ -274,7 +274,7 @@ END;
 CREATE OR REPLACE procedure update_contents_from_others(request_id_in NUMBER, transform_id_in NUMBER) AS
 BEGIN
     update (select c.content_id, c.substatus as c_substatus, t.substatus as t_substatus from  contents c inner join
-    (select content_id, substatus from contents where request_id = request_id_in and content_relation_type = 1 and status != 0) t
+    (select content_id, substatus from contents where request_id = request_id_in and content_relation_type = 1) t
     on c.content_dep_id = t.content_id where c.request_id = request_id_in and c.transform_id = transform_id_in and c.substatus != t.substatus) set c_substatus = t_substatus;
 END;
 
@@ -282,6 +282,12 @@ END;
 CREATE OR REPLACE procedure update_contents_to_others(request_id_in NUMBER, transform_id_in NUMBER) AS
 BEGIN
     update (select c.content_id, c.substatus as c_substatus, t.substatus as t_substatus from  contents c inner join
-    (select content_id, substatus from contents where request_id = request_id_in and transform_id = transform_id_in and content_relation_type = 1 and status != substatus) t
+    (select content_id, substatus from contents where request_id = request_id_in and transform_id = transform_id_in and content_relation_type = 1) t
     on c.content_dep_id = t.content_id where c.request_id = request_id_in and c.substatus != t.substatus) set c_substatus = t_substatus;
 END;
+
+
+
+-- 2023.02.14
+drop index CONTENTS_REQ_TF_COLL_IDX
+CREATE INDEX CONTENTS_REQ_TF_COLL_IDX ON CONTENTS (request_id, transform_id, workload_id, coll_id, status, substatus) LOCAL;
