@@ -6,7 +6,7 @@
 # http://www.apache.org/licenses/LICENSE-2.0OA
 #
 # Authors:
-# - Wen Guan, <wen.guan@cern.ch>, 2019 - 2022
+# - Wen Guan, <wen.guan@cern.ch>, 2019 - 2023
 
 import datetime
 import random
@@ -36,6 +36,9 @@ class Poller(BaseAgent):
 
     def __init__(self, num_threads=1, poll_period=10, retries=3, retrieve_bulk_size=2,
                  name='Poller', message_bulk_size=1000, **kwargs):
+        self.set_max_workers()
+        num_threads = self.max_number_workers
+
         super(Poller, self).__init__(num_threads=num_threads, name=name, **kwargs)
         self.config_section = Sections.Carrier
         self.poll_period = int(poll_period)
@@ -184,6 +187,13 @@ class Poller(BaseAgent):
                 processing['update_processing']['parameters']['locking'] = ProcessingLocking.Idle
                 # self.logger.debug("wen: %s" % str(processing))
                 processing['update_processing']['parameters']['updated_at'] = datetime.datetime.utcnow()
+                # check update_processing status
+                if 'status' in processing['update_processing']['parameters']:
+                    new_status = processing['update_processing']['parameters']['status']
+                    if new_status == ProcessingStatus.Submitting and processing_model['status'].value > ProcessingStatus.Submitting.value:
+                        processing['update_processing']['parameters']['status'] = ProcessingStatus.Submitted
+
+                self.logger.info(log_prefix + "update_processing: %s" % (processing['update_processing']['parameters']))
 
                 retry = True
                 retry_num = 0
@@ -372,6 +382,7 @@ class Poller(BaseAgent):
                             event_content['has_updates'] = True
                         if is_process_terminated(pr['substatus']):
                             event_content['Terminated'] = True
+                        self.logger.info(log_pre + "TriggerProcessingEvent(processing_id: %s)" % pr['processing_id'])
                         event = TriggerProcessingEvent(publisher_id=self.id, processing_id=pr['processing_id'], content=event_content,
                                                        counter=original_event._counter)
                         self.event_bus.send(event)
