@@ -24,7 +24,7 @@ from idds.common.utils import json_dumps
 from idds.core import messages as core_messages, catalog as core_catalog
 from idds.agents.common.baseagent import BaseAgent
 # from idds.agents.common.eventbus.event import TerminatedProcessingEvent
-from idds.agents.common.eventbus.event import TriggerProcessingEvent
+from idds.agents.common.eventbus.event import MsgTriggerProcessingEvent
 
 from .utils import handle_messages_processing
 
@@ -36,7 +36,7 @@ class Receiver(BaseAgent):
     Receiver works to receive workload management messages to update task/job status.
     """
 
-    def __init__(self, num_threads=1, bulk_message_delay=5, bulk_message_size=2000,
+    def __init__(self, num_threads=1, bulk_message_delay=30, bulk_message_size=2000,
                  random_delay=None, **kwargs):
         super(Receiver, self).__init__(num_threads=num_threads, name='Receiver', **kwargs)
         self.config_section = Sections.Carrier
@@ -108,16 +108,17 @@ class Receiver(BaseAgent):
                     for pr_id in update_processings:
                         # self.logger.info(log_prefix + "TerminatedProcessingEvent(processing_id: %s)" % pr_id)
                         # event = TerminatedProcessingEvent(publisher_id=self.id, processing_id=pr_id)
-                        self.logger.info(log_prefix + "TriggerProcessingEvent(processing_id: %s)" % pr_id)
-                        event = TriggerProcessingEvent(publisher_id=self.id, processing_id=pr_id)
+                        self.logger.info(log_prefix + "MsgTriggerProcessingEvent(processing_id: %s)" % pr_id)
+                        event = MsgTriggerProcessingEvent(publisher_id=self.id, processing_id=pr_id)
                         self.event_bus.send(event)
 
                     for pr_id in terminated_processings:
-                        self.logger.info(log_prefix + "TriggerProcessingEvent(processing_id: %s)" % pr_id)
-                        event = TriggerProcessingEvent(publisher_id=self.id, processing_id=pr_id, content={'Terminated': True, 'source': 'Receiver'})
+                        self.logger.info(log_prefix + "MsgTriggerProcessingEvent(processing_id: %s)" % pr_id)
+                        event = MsgTriggerProcessingEvent(publisher_id=self.id, processing_id=pr_id, content={'Terminated': True, 'source': 'Receiver'})
                         self.event_bus.send(event)
 
                     time_delay = self.bulk_message_delay - (time.time() - time_start)
+                    time_delay = self.bulk_message_delay
                     if time_delay > 0:
                         time.sleep(time_delay)
                 except IDDSException as error:
