@@ -13,12 +13,19 @@ from idds.workflowv2.workflow import Workflow            # noqa F401
 from idds.workflowv2.work import Work                    # noqa F401
 
 from idds.orm import contents as orm_contents       # noqa F401
+from idds.core import catalog as core_catalog       # noqa F401
 
 
 setup_logging(__name__)
 
-request_id = 486
-transform_id = 3027   # 3028, 3029
+request_id = 3347
+transform_id = 26788   # 3028, 3029
 
-ret = orm_contents.update_contents_from_others_by_dep_id(request_id=request_id, transform_id=transform_id)
+# ret = core_catalog.update_contents_to_others_by_dep_id(request_id=request_id, transform_id=transform_id)
+# print(ret)
+
+# ret = core_catalog.update_contents_from_others_by_dep_id(request_id=request_id, transform_id=transform_id)
+# print(ret)
+
+ret = core_catalog.get_updated_transforms_by_content_status(request_id=3350)
 print(ret)
